==> owncloud-app-contacts-2%3A1.3.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/fr.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contacts",
    "Address book name" : "Nom du carnet d'adresses",
    "Import" : "Importer",
    "No contacts in here" : "Aucun contact",
    "Name" : "Nom",
    "Organization" : "Société",
    "Title" : "Titre",
    "Add field ..." : "Ajouter un champ ...",
    "Add contact" : "Ajouter un contact",
    "No search result for {query}" : "Aucun résultat pour {query}",
    "All contacts" : "Tous les contacts",
    "Not grouped" : "Non groupés",
    "Post Office Box" : "Boîte postale",
    "Postal Code" : "Code postal ",
    "City" : "Ville",
    "State or province" : "État ou région",
    "Country" : "Pays",
    "Address" : "Adresse",
    "(new group)" : "(nouveau groupe)",
    "New contact" : "Nouveau contact",
    "{addressbook} shared by {owner}" : "{addressbook} partagé par {owner}",
    "No contacts in file. Only VCard files are allowed." : "Aucun contact dans ce fichier. Seulement les fichiers VCard sont autorisés.",
    "Nickname" : "Surnom",
    "Notes" : "Notes",
    "Website" : "Site web",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Privé(e)",
    "Work" : "Pro",
    "Other" : "Autre",
    "Groups" : "Groupes",
    "Birthday" : "Anniversaire",
    "Email" : "Adresse e-mail",
    "Instant messaging" : "Messagerie instantanée",
    "Phone" : "Téléphone",
    "Mobile" : "Mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax personnel",
    "Fax work" : "Fax pro",
    "Pager" : "Bipeur",
    "Voice" : "Voix",
    "Social Network" : "Réseau Social",
    "Settings" : "Paramètres"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/fr.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contacts",
    "Address book name" : "Nom du carnet d'adresses",
    "Import" : "Importer",
    "The selected image is too big (max 1MB)" : "L'image sélectionnée est trop volumineuse (1Mo max)",
    "No contacts in here" : "Aucun contact",
    "Name" : "Nom",
    "Organization" : "Société",
    "Title" : "Titre",
    "Add field ..." : "Ajouter un champ ...",
    "+ New contact" : "+ Nouveau contact",
    "No search result for {query}" : "Aucun résultat pour {query}",
    "_%n contact_::_%n contacts_" : ["%n contact","%n contacts"],
    "Post office box" : "Boîte postale",
    "Postal code" : "Code postal",
    "City" : "Ville",
    "State or province" : "État ou région",
    "Country" : "Pays",
    "Address" : "Adresse",
    "(new group)" : "(nouveau groupe)",
    "Last name" : "Nom",
    "First name" : "Prénom",
    "Additional names" : "Noms supplémentaires",
    "Prefix" : "Préfixe",
    "Suffix" : "Suffixe",
    "All contacts" : "Tous les contacts",
    "Not grouped" : "Non groupés",
    "New contact" : "Nouveau contact",
    "{addressbook} shared by {owner}" : "{addressbook} partagé par {owner}",
    "No contacts in file. Only VCard files are allowed." : "Aucun contact dans ce fichier. Seulement les fichiers VCard sont autorisés.",
    "Nickname" : "Surnom",
    "Detailed name" : "Nom complet",
    "Notes" : "Notes",
    "Website" : "Site web",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Privé(e)",
    "Work" : "Pro",
    "Other" : "Autre",
    "Groups" : "Groupes",
    "Birthday" : "Anniversaire",
    "Anniversary" : "Anniversaire",
    "Date of death" : "Date de décès",
    "Email" : "Adresse e-mail",
    "Instant messaging" : "Messagerie instantanée",
    "Phone" : "Téléphone",
    "Mobile" : "Mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax personnel",
    "Fax work" : "Fax pro",
    "Pager" : "Bipeur",
    "Voice" : "Voix",
    "Social network" : "Réseau social",
    "Settings" : "Paramètres"
},
"nplurals=2; plural=(n > 1);");
